==> nextcloud-29.0.12.tgz: nextcloud/apps/workflowengine/l10n/is.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "Uppgefinn virki er ógildur",
    "The given regular expression is invalid" : "Uppgefin regluleg segð er ógild",
    "The given file size is invalid" : "Uppgefin stærð er ógild",
    "The given tag id is invalid" : "Uppgefið auðkenni merkis er ógilt",
    "The given IP range is invalid" : "Uppgefna IP-vistfangasviðið er ógilt",
    "The given IP range is not valid for IPv4" : "Uppgefna IP-vistfangasviðið er ekki gilt fyrir IPv4",
    "The given IP range is not valid for IPv6" : "Uppgefna IP-vistfangasviðið er ekki gilt fyrir IPv6",
    "The given time span is invalid" : "Uppgefið tímasvið er ógilt",
    "The given start time is invalid" : "Uppgefinn upphafstími er ógildur",
    "The given end time is invalid" : "Uppgefinn lokatími er ógildur",
    "The given group does not exist" : "Uppgefinn hópur er ekki til",
    "File" : "Skrá",
    "Operation #%s does not exist" : "Aðgerðin #%s er ekki til",
    "Operation %s does not exist" : "Aðgerðin %s er ekki til",
    "Operation %s is invalid" : "Aðgerðin %s er ógild",
    "Check %s does not exist" : "Athugunin %s er ekki til",
    "Check %s is invalid" : "Athugunin %s er ógild",
    "Check #%s does not exist" : "Athugunin #%s er ekki til",
    "Check %s is invalid or does not exist" : "Athugunin %s er ógild eða er ekki til",
    "Flow" : "Flæði",
    "Remove filter" : "Fjarlægja síu",
    "Folder" : "Mappa",
    "Images" : "Myndir",
    "Files WebDAV" : "WebDAV skráa",
    "Android client" : "Android-biðlari",
    "iOS client" : "iOS-biðlari",
    "Desktop client" : "Skjáborðsforrit",
    "Thunderbird & Outlook addons" : "Thunderbird & Outlook viðbætur",
    "Select groups" : "Veldu hópa",
    "Groups" : "Hópar",
    "Add new flow" : "Bæta við nýju flæði",
    "Cancel" : "Hætta við",
    "Delete" : "Eyða",
    "Active" : "Virkt",
    "Save" : "Vista",
    "Available flows" : "Tiltæk flæði",
    "More flows" : "Fleiri flæði",
    "Browse the App Store" : "Flakka um forritasafnið",
    "Show less" : "Birta minna",
    "Show more" : "Birta meira",
    "Configured flows" : "Uppsett flæði",
    "Your flows" : "Flæðin þín",
    "matches" : "samsvarar",
    "does not match" : "samsvarar ekki",
    "is" : "er",
    "is not" : "er ekki",
    "File name" : "Skráarheiti",
    "File MIME type" : "MIME-skráartegund",
    "File size (upload)" : "Skráarstærð (innsending)",
    "less" : "minna en",
    "less or equals" : "minna eða jafnt",
    "greater or equals" : "stærra eða jafnt",
    "greater" : "meira en",
    "Request remote address" : "Biðja um fjartengt vistfang",
    "matches IPv4" : "samsvarar IPv4",
    "does not match IPv4" : "samsvarar ekki IPv4",
    "matches IPv6" : "samsvarar IPv6",
    "does not match IPv6" : "samsvarar ekki IPv6",
    "File system tag" : "Skráakerfismerki",
    "is tagged with" : "er merkt með",
    "is not tagged with" : "er ekki merkt með",
    "Request URL" : "Slóð á beiðni",
    "Request time" : "Tími beiðnar",
    "between" : "á milli",
    "not between" : "er ekki á milli",
    "Request user agent" : "Biðja um notandaforrit",
    "is member of" : "er meðlimur í ",
    "is not member of" : "er ekki meðlimur í"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");

==> nextcloud-30.0.5.tgz: nextcloud/apps/workflowengine/l10n/is.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "Uppgefinn virki er ógildur",
    "The given regular expression is invalid" : "Uppgefin regluleg segð er ógild",
    "The given file size is invalid" : "Uppgefin stærð er ógild",
    "The given tag id is invalid" : "Uppgefið auðkenni merkis er ógilt",
    "The given IP range is invalid" : "Uppgefna IP-vistfangasviðið er ógilt",
    "The given IP range is not valid for IPv4" : "Uppgefna IP-vistfangasviðið er ekki gilt fyrir IPv4",
    "The given IP range is not valid for IPv6" : "Uppgefna IP-vistfangasviðið er ekki gilt fyrir IPv6",
    "The given time span is invalid" : "Uppgefið tímasvið er ógilt",
    "The given start time is invalid" : "Uppgefinn upphafstími er ógildur",
    "The given end time is invalid" : "Uppgefinn lokatími er ógildur",
    "The given group does not exist" : "Uppgefinn hópur er ekki til",
    "File" : "Skrá",
    "Operation #%s does not exist" : "Aðgerðin #%s er ekki til",
    "Operation %s does not exist" : "Aðgerðin %s er ekki til",
    "Operation %s is invalid" : "Aðgerðin %s er ógild",
    "Check %s does not exist" : "Athugunin %s er ekki til",
    "Check %s is invalid" : "Athugunin %s er ógild",
    "Check #%s does not exist" : "Athugunin #%s er ekki til",
    "Check %s is invalid or does not exist" : "Athugunin %s er ógild eða er ekki til",
    "Flow" : "Flæði",
    "Folder" : "Mappa",
    "Images" : "Myndir",
    "Files WebDAV" : "WebDAV skráa",
    "Android client" : "Android-biðlari",
    "iOS client" : "iOS-biðlari",
    "Desktop client" : "Skjáborðsforrit",
    "Thunderbird & Outlook addons" : "Thunderbird & Outlook viðbætur",
    "Select groups" : "Veldu hópa",
    "Groups" : "Hópar",
    "Add new flow" : "Bæta við nýju flæði",
    "Cancel" : "Hætta við",
    "Delete" : "Eyða",
    "Active" : "Virkt",
    "Save" : "Vista",
    "Available flows" : "Tiltæk flæði",
    "More flows" : "Fleiri flæði",
    "Browse the App Store" : "Flakka um forritasafnið",
    "Configured flows" : "Uppsett flæði",
    "Your flows" : "Flæðin þín",
    "matches" : "samsvarar",
    "does not match" : "samsvarar ekki",
    "is" : "er",
    "is not" : "er ekki",
    "File name" : "Skráarheiti",
    "File MIME type" : "MIME-skráartegund",
    "File size (upload)" : "Skráarstærð (innsending)",
    "less" : "minna en",
    "less or equals" : "minna eða jafnt",
    "greater or equals" : "stærra eða jafnt",
    "greater" : "meira en",
    "Request remote address" : "Biðja um fjartengt vistfang",
    "matches IPv4" : "samsvarar IPv4",
    "does not match IPv4" : "samsvarar ekki IPv4",
    "matches IPv6" : "samsvarar IPv6",
    "does not match IPv6" : "samsvarar ekki IPv6",
    "File system tag" : "Skráakerfismerki",
    "is tagged with" : "er merkt með",
    "is not tagged with" : "er ekki merkt með",
    "Request URL" : "Slóð á beiðni",
    "Request time" : "Tími beiðnar",
    "between" : "á milli",
    "not between" : "er ekki á milli",
    "Request user agent" : "Biðja um notandaforrit",
    "is member of" : "er meðlimur í ",
    "is not member of" : "er ekki meðlimur í",
    "User group membership" : "Notandi er meðlimur í hópum"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
